@@ -1,9 +1,7 @@
-/* Copyright (C) 2001-2017 Peter Selinger.
+/* Copyright (C) 2001-2019 Peter Selinger.
    This file is part of Potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
-#define _XOPEN_SOURCE 500
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -101,12 +99,12 @@ struct backend_s {
 typedef struct backend_s backend_t;  
 
 static backend_t backend[] = {
+  { "svg",        ".svg", 0, 0, 0,   NULL,     page_svg,     NULL,     1 },
+  { "pdf",        ".pdf", 0, 0, 1,   init_pdf, page_pdf,     term_pdf, 1 },
+  { "pdfpage",    ".pdf", 1, 0, 1,   init_pdf, page_pdfpage, term_pdf, 1 },
   { "eps",        ".eps", 0, 0, 0,   NULL,     page_eps,     NULL,     1 },
   { "postscript", ".ps",  1, 0, 1,   init_ps,  page_ps,      term_ps,  1 },
   { "ps",         ".ps",  1, 0, 1,   init_ps,  page_ps,      term_ps,  1 },
-  { "pdf",        ".pdf", 0, 0, 1,   init_pdf, page_pdf,     term_pdf, 1 },
-  { "pdfpage",    ".pdf", 1, 0, 1,   init_pdf, page_pdfpage, term_pdf, 1 },
-  { "svg",        ".svg", 0, 0, 0,   NULL,     page_svg,     NULL,     1 },
   { "dxf",        ".dxf", 0, 1, 0,   NULL,     page_dxf,     NULL,     1 },
   { "geojson",    ".json",0, 1, 0,   NULL,     page_geojson, NULL,     1 },
   { "pgm",        ".pgm", 0, 1, 1,   NULL,     page_pgm,     NULL,     1 },
@@ -203,12 +201,12 @@ static void usage(FILE *f) {
   fprintf(f, " --                         - end of options; 0 or more input filenames follow\n");
   fprintf(f, "Backend selection:\n");
   fprintf(f, " -b, --backend <name>       - select backend by name\n");
-  fprintf(f, " -e, --eps                  - EPS backend (encapsulated PostScript) (default)\n");
-  fprintf(f, " -p, --postscript           - PostScript backend\n");
-  fprintf(f, " -s, --svg                  - SVG backend (scalable vector graphics)\n");
-  fprintf(f, " -g, --pgm                  - PGM backend (portable greymap)\n");
+  fprintf(f, " -b svg, -s, --svg          - SVG backend (scalable vector graphics)\n");
   fprintf(f, " -b pdf                     - PDF backend (portable document format)\n");
   fprintf(f, " -b pdfpage                 - fixed page-size PDF backend\n");
+  fprintf(f, " -b eps, -e, --eps          - EPS backend (encapsulated PostScript) (default)\n");
+  fprintf(f, " -b ps, -p, --postscript    - PostScript backend\n");
+  fprintf(f, " -b pgm, -g, --pgm          - PGM backend (portable greymap)\n");
   fprintf(f, " -b dxf                     - DXF backend (drawing interchange format)\n");
   fprintf(f, " -b geojson                 - GeoJSON backend\n");
   fprintf(f, " -b gimppath                - Gimppath backend (GNU Gimp)\n");
@@ -487,13 +485,13 @@ static void dopts(int ac, char *av[]) {
       break;
     case 'v':
     case 'V':
-      fprintf(stdout, "" POTRACE " " VERSION ". Copyright (C) 2001-2017 Peter Selinger.\n");
+      fprintf(stdout, "" POTRACE " " VERSION ". Copyright (C) 2001-2019 Peter Selinger.\n");
       fprintf(stdout, "Library version: %s\n", potrace_version());
       show_defaults(stdout);
       exit(0);
       break;
     case 'l':
-      fprintf(stdout, "" POTRACE " " VERSION ". Copyright (C) 2001-2017 Peter Selinger.\n\n");
+      fprintf(stdout, "" POTRACE " " VERSION ". Copyright (C) 2001-2019 Peter Selinger.\n\n");
       license(stdout);
       exit(0);
       break;
@@ -589,6 +587,9 @@ static void dopts(int ac, char *av[]) {
 	fprintf(stderr, "" POTRACE ": invalid angle -- %s\n", optarg);
 	exit(1);
       }
+      if (info.angle <= -180 || info.angle > 180) {
+        info.angle -= 360 * ceil(info.angle / 360 - 0.5);
+      }
       break;
     case 'P':
       matches = 0;
@@ -613,8 +614,8 @@ static void dopts(int ac, char *av[]) {
       }
       parse_dimensions(optarg, &p, &dimx, &dimy);
       if (*p == 0) {
-	info.paperwidth = (int)rint(double_of_dim(dimx, DEFAULT_DIM));
-	info.paperheight = (int)rint(double_of_dim(dimy, DEFAULT_DIM));
+	info.paperwidth = (int)round(double_of_dim(dimx, DEFAULT_DIM));
+	info.paperheight = (int)round(double_of_dim(dimy, DEFAULT_DIM));
 	break;
       }
       if (matches == 0) {
